//
//  ContentView.swift
//  TaskList
//
//  Created by Daniel Price on 11/4/19.
//  Copyright © 2019 Twice as Tall Integration. All rights reserved.
//

import SwiftUI

struct ContentView: View {
  //create an instance of TaskStore
  @ObservedObject var taskStore: TaskStore
  
  //modal sheet
  @State var modalIsPresented = false
  
  var body: some View {
    /*with no id
     List(taskStore.tasks.indices) { index in
     Text(self.taskStore.tasks[index].name)
     }*/
    
    /*using uuid but no Identifiable protocol
     List(taskStore.tasks, id: \.id) { task in
     Text(task.name)
     }*/

    /* Prior to using Row view
     //select Text(task.name) and embed in subview
    NavigationView {
      List {
        ForEach(taskStore.tasks) { task in
          Text(task.name)
        }
        .onMove { sourceIndices, destinationIndex in
          self.taskStore.tasks.move(fromOffsets: sourceIndices, toOffset: destinationIndex)
        }
        .onDelete{ indexSet in
          self.taskStore.tasks.remove(atOffsets: indexSet)
        }
      }
      .navigationBarTitle("Tasks")
      .navigationBarItems(
        leading:
          EditButton(),
        trailing:
          Button(
            action: {self.modalIsPresented = true}
          ) {
            Image(systemName: "plus")
          }
      )
    }
    .sheet(isPresented: $modalIsPresented) {
      NewTaskView(taskStore: self.taskStore)
    }
  }
}*/
    
    NavigationView {
          List {
            ForEach(taskStore.prioritizedTasks) { index in
              SectionView(prioritizedTasks: self.$taskStore.prioritizedTasks[index])
            }
          }
          .navigationBarTitle("Tasks")
          .navigationBarItems(
            leading:
              EditButton(),
            trailing:
              Button(
                action: {self.modalIsPresented = true}
              ) {
                Image(systemName: "plus")
              }
          )
        }
        .sheet(isPresented: $modalIsPresented) {
          NewTaskView(taskStore: self.taskStore)
        }
      }
}


struct ContentView_Previews: PreviewProvider {
  static var previews: some View {
    ContentView(taskStore: TaskStore())
  }
}


/*result of embed in subview
//but easier to create a new SwiftUIView which would include the preview
struct RowView: View {
  var task: Task
  var body: some View {
    Text(task.name)
  }
}*/
